@@ -29,6 +29,9 @@ class AllFeed(Feed):
     def item_title(self, item):
         return item.title
 
+    def item_pubdate(self, item):
+        return item.creation_date
+
     def item_link(self, item):
         return item.get_absolute_url()
 
