@@ -35,8 +35,9 @@ class Post(models.Model):
     thread_id = models.CharField(max_length=32, blank=True) # DISQUS
 
     if "rgallery" in conf.INSTALLED_APPS:
-        from rgallery.models import Photo
+        from rgallery.models import Photo, Video
         photo = models.ManyToManyField(Photo, related_name="photo", blank=True, null=True)
+        video = models.ManyToManyField(Video, related_name="myvideo", blank=True, null=True)
 
     def set_tags(self, tags):
         Tag.objects.update_tags(self, tags)
